.container {
    padding: 0;
    margin: 0;
    width: 100%;
}
.container > div > .row {
    margin-top: 38px;
}
.navbar-default {
    background: #2e3641;
    color: #fff;
}
.brand-logo img {
    max-width: 100%;
}
.panel-default > .panel-heading,
.panel-body {
    color: #fff;
}

.row {
    margin: 0;
}
.dashboard-sidebar .nav {
    background: #2e3641;
}
.dashboard-sidebar .nav a {
    color: #fff;
    font-size: 14px;
    font-weight: 100;
    line-height: 20px;
}
.dashboard-sidebar .nav .active > a {
    color: #6098d1;
}
.dashboard-sidebar .nav .dropdown.active > a:focus,
.dashboard-sidebar .nav .dropdown.active > a:hover {
    color: #6098d1;
}
.dashboard-sidebar .nav > li > a {
    padding: 15px 15px;
    border-bottom: 1px solid #5E5F68;
}
.panel-body h4 {
    margin-top: 0;
    font-weight: 300;
}
.panel-body h1 {
    padding-top: 5px;
    margin-top: 0;
    margin-bottom: 27px;
    font-weight: 300;
    font-size: 30px;
}
.panel-body h1 strong {
    margin-right: 10px;
    margin-top: -10px;
    float: left;
    font-size: 80px;
}


.container .body-footer {
    position: relative;
}
.col1 {
    display: block;
    width: 50%;
    float: left;
    height: 100%;
    vertical-align: top;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    padding: 0 5px 0 0;
    margin: 0;
}
.container a {
    color: #5995cf;
}
.grp-pulldown-container .grp-pulldown-handler,
.grp-pulldown-container .grp-pulldown-handler:hover,
.grp-pulldown-container.grp-pulldown-state-open .grp-pulldown-handler,
.grp-pulldown-container.grp-pulldown-state-open .grp-pulldown-handler:hover {
    background-image: none;
}
