{% extends "admin/base_site.html" %}
{% load cache gipsy_dashboard %}

<!-- COLTYPE/BODYCLASS-- >
{% block bodyclass %}dashboard{% endblock %}
{% block content-class %}content-grid{% endblock %}

{% block header %}{% endblock %}

<!-- CONTENT -->
{% block content %}
{% if user.is_active and user.is_staff %}
<div class="gipsy_dashboard">
    {% gipsy_dashboard_cache_time as cache_time %}
    {% cache cache_time gipsy_dashboard %}
        {% if dashboard.has_rows %}
            {% for row in dashboard.rows %}
                <div class="row">{% include 'gipsy/dashboard/widgets_list.html' with widgets=row %}</div>
            {% endfor %}
        {% else %}
            {% include 'gipsy/dashboard/widgets_list.html' with widgets=dashboard.widgets %}
        {% endif %}
    {% endcache %}    
</div>
{% endif %}
{% endblock %}

{% block footer %}{% endblock %}
